@@ -1,7 +1,8 @@
+import math
 import re
 
 from flask import abort, request, render_template
-from peewee import Model, DoesNotExist
+from peewee import Model, DoesNotExist, SelectQuery
 
 
 def get_object_or_404(query_or_model, **query):
@@ -22,18 +23,18 @@ class PaginatedQuery(object):
     def __init__(self, query_or_model, paginate_by):
         self.paginate_by = paginate_by
         
-        if isinstance(query_or_model, Model):
-            self.model = query_or_model
-            self.query = self.model.select()
-        else:
+        if isinstance(query_or_model, SelectQuery):
             self.query = query_or_model
             self.model = self.query.model
+        else:
+            self.model = query_or_model
+            self.query = self.model.select()
     
     def get_page(self):
         return int(request.args.get(self.page_var) or 1)
     
     def get_pages(self):
-        return self.query.count() / self.paginate_by + 1
+        return math.ceil(float(self.query.count()) / self.paginate_by)
     
     def get_list(self):
         return self.query.paginate(self.get_page(), self.paginate_by)
